"""Pylint import checking module."""

from pylint_absolute_imports.checker import AbsoluteImportChecker


def register(linter):
    """Add the current checker to pylint."""
    linter.register_checker(AbsoluteImportChecker(linter))



"""Strict check of the import."""
from astroid import ImportFrom  # type: ignore
from pylint.interfaces import IAstroidChecker  # type: ignore
from pylint.checkers import BaseChecker  # type: ignore


def is_relative(node: ImportFrom) -> bool:
    """Returns True, if import is relative, False otherwise. """
    return node.level is not None and node.level > 0


class AbsoluteImportChecker(BaseChecker):

    """Pylint checker for imports."""

    __implements__ = IAstroidChecker

    name = 'relative-import'
    priority = -1
    msgs = {
        'C0001': (
            'Unacceptable relative import',
            name,
            'Consider using absolute import',
        ),
    }

    def visit_importfrom(self, node: ImportFrom):
        """Look for relative imports."""
        if is_relative(node):
            self.add_message(
                'C0001',
                line=node.lineno,
                node=node,
                col_offset=node.col_offset,
            )



"""Install the package."""
from setuptools import setup  # type: ignore


setup(
    name='pylint_absolute_imports',
    version='1.0',
    packages=['pylint_absolute_imports'],
    url='https://github.com/quentinn42/pylint_absolute_imports',
    license='MIT License',
    author='Quentin Lieumont',
    author_email='quentin@lieumont.fr',
    description=(
        'Pylint plugin which adds linter error for relatives imports.'
        'Read more about imports at https://peps.python.org/pep-0008/#imports'
    ),
    classifiers=(
        'Development Status :: 4 - Beta',
        'Environment :: Plugins',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ),
    install_requires=(
        'pylint>=2.5.0,<3',
    )
)
